// Compiled by ClojureScript 1.10.891 {:static-fns true, :optimize-constants false, :target :nodejs, :nodejs-rt false, :optimizations :advanced}
goog.provide('alphabase.bytes');
goog.require('cljs.core');
/**
 * Coerces a number to a byte value.
 */
alphabase.bytes.to_byte = (function alphabase$bytes$to_byte(x){
return x;
});
/**
 * Coerces a byte value to a number.
 */
alphabase.bytes.from_byte = (function alphabase$bytes$from_byte(x){
return x;
});
/**
 * Reads a byte value out of an array and coerces it to a number.
 */
alphabase.bytes.get_byte = (function alphabase$bytes$get_byte(array,i){
return alphabase.bytes.from_byte((array[i]));
});
/**
 * Sets a byte value in an array after coercing it from a number.
 */
alphabase.bytes.set_byte = (function alphabase$bytes$set_byte(array,i,x){
return (array[i] = alphabase.bytes.to_byte(x));
});
/**
 * Return a sequence of the bytes in an array, after coercion.
 */
alphabase.bytes.byte_seq = (function alphabase$bytes$byte_seq(array){
if(cljs.core.truth_(array)){
return cljs.core.map.cljs$core$IFn$_invoke$arity$2((function (p1__32659_SHARP_){
return (array[p1__32659_SHARP_]);
}),cljs.core.range.cljs$core$IFn$_invoke$arity$1(array.length));
} else {
return null;
}
});
/**
 * True if the argument is a byte array compatible with this library.
 */
alphabase.bytes.bytes_QMARK_ = (function alphabase$bytes$bytes_QMARK_(x){
return (((x instanceof Uint8Array)) || ((((x instanceof Array)) && (((cljs.core.empty_QMARK_(x)) || (cljs.core.integer_QMARK_(cljs.core.first(x))))))));
});
/**
 * Returns true if two byte sequences are the same length and have the same
 *   byte content.
 */
alphabase.bytes.bytes_EQ_ = (function alphabase$bytes$bytes_EQ_(a,b){
var and__4251__auto__ = alphabase.bytes.bytes_QMARK_(a);
if(and__4251__auto__){
var and__4251__auto____$1 = alphabase.bytes.bytes_QMARK_(b);
if(and__4251__auto____$1){
var a__$1 = a;
var b__$1 = b;
var and__4251__auto____$2 = cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(a__$1.length,b__$1.length);
if(and__4251__auto____$2){
var i = (0);
while(true){
if((i < a__$1.length)){
if(cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(alphabase.bytes.get_byte(a__$1,i),alphabase.bytes.get_byte(b__$1,i))){
var G__32660 = (i + (1));
i = G__32660;
continue;
} else {
return false;
}
} else {
return true;
}
break;
}
} else {
return and__4251__auto____$2;
}
} else {
return and__4251__auto____$1;
}
} else {
return and__4251__auto__;
}
});
/**
 * Creates a new array to hold byte data.
 */
alphabase.bytes.byte_array = (function alphabase$bytes$byte_array(length){
return (new Uint8Array((new ArrayBuffer(length))));
});
/**
 * Copies bytes from one array to another.
 * 
 *   - If only a source is given, returns a full copy of the byte array.
 *   - If a source and a destination with offset are given, copies all of the
 *  bytes from the source into the destination at that offset. Returns the
 *  number of bytes copied.
 *   - If all arguments are given, copies `length` bytes from the source at the
 *  given offset to the destination at its offset. Returns the number of bytes
 *  copied.
 */
alphabase.bytes.copy = (function alphabase$bytes$copy(var_args){
var G__32662 = arguments.length;
switch (G__32662) {
case 1:
return alphabase.bytes.copy.cljs$core$IFn$_invoke$arity$1((arguments[(0)]));

break;
case 3:
return alphabase.bytes.copy.cljs$core$IFn$_invoke$arity$3((arguments[(0)]),(arguments[(1)]),(arguments[(2)]));

break;
case 5:
return alphabase.bytes.copy.cljs$core$IFn$_invoke$arity$5((arguments[(0)]),(arguments[(1)]),(arguments[(2)]),(arguments[(3)]),(arguments[(4)]));

break;
default:
throw (new Error(["Invalid arity: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(arguments.length)].join('')));

}
});

(alphabase.bytes.copy.cljs$core$IFn$_invoke$arity$1 = (function (src){
var dst = alphabase.bytes.byte_array(src.length);
alphabase.bytes.copy.cljs$core$IFn$_invoke$arity$3(src,dst,(0));

return dst;
}));

(alphabase.bytes.copy.cljs$core$IFn$_invoke$arity$3 = (function (src,dst,dst_offset){
return alphabase.bytes.copy.cljs$core$IFn$_invoke$arity$5(src,(0),dst,dst_offset,src.length);
}));

(alphabase.bytes.copy.cljs$core$IFn$_invoke$arity$5 = (function (src,src_offset,dst,dst_offset,length){
var n__4741__auto___32664 = length;
var i_32665 = (0);
while(true){
if((i_32665 < n__4741__auto___32664)){
alphabase.bytes.set_byte(dst,(i_32665 + dst_offset),alphabase.bytes.get_byte(src,(i_32665 + src_offset)));

var G__32666 = (i_32665 + (1));
i_32665 = G__32666;
continue;
} else {
}
break;
}

return length;
}));

(alphabase.bytes.copy.cljs$lang$maxFixedArity = 5);

/**
 * Initialize a new array with the given sequence of byte values.
 */
alphabase.bytes.init_bytes = (function alphabase$bytes$init_bytes(values){
var length = cljs.core.count(values);
var data = alphabase.bytes.byte_array(length);
var n__4741__auto___32667 = length;
var i_32668 = (0);
while(true){
if((i_32668 < n__4741__auto___32667)){
alphabase.bytes.set_byte(data,i_32668,cljs.core.nth.cljs$core$IFn$_invoke$arity$2(values,i_32668));

var G__32669 = (i_32668 + (1));
i_32668 = G__32669;
continue;
} else {
}
break;
}

return data;
});
/**
 * Returns a byte array `length` bytes long with random content.
 */
alphabase.bytes.random_bytes = (function alphabase$bytes$random_bytes(length){
var data = alphabase.bytes.byte_array(length);
var n__4741__auto___32670 = length;
var i_32671 = (0);
while(true){
if((i_32671 < n__4741__auto___32670)){
alphabase.bytes.set_byte(data,i_32671,cljs.core.rand_int((256)));

var G__32672 = (i_32671 + (1));
i_32671 = G__32672;
continue;
} else {
}
break;
}

return data;
});
/**
 * Lexicographically compares two byte-arrays for order. Returns a negative
 *   number, zero, or a positive number if `a` is less than, equal to, or greater
 *   than `b`, respectively.
 * 
 *   This ranking compares each byte in the keys in order; the first byte which
 *   differs determines the ordering; if the byte in `a` is less than the byte in
 *   `b`, `a` ranks before `b`, and vice versa.
 * 
 *   If the keys differ in length, and all the bytes in the shorter key match the
 *   longer key, the shorter key ranks first.
 */
alphabase.bytes.compare = (function alphabase$bytes$compare(a,b){
var prefix_len = (function (){var x__4339__auto__ = a.length;
var y__4340__auto__ = b.length;
return ((x__4339__auto__ < y__4340__auto__) ? x__4339__auto__ : y__4340__auto__);
})();
var i = (0);
while(true){
if((i < prefix_len)){
var ai = alphabase.bytes.get_byte(a,i);
var bi = alphabase.bytes.get_byte(b,i);
if(cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(ai,bi)){
var G__32673 = (i + (1));
i = G__32673;
continue;
} else {
return (ai - bi);
}
} else {
return (a.length - b.length);
}
break;
}
});
/**
 * Copy a slice (defined by offset, length) from a byte array.
 * 
 *   Omitting the slice `len` argument will copy remainder of
 *   `src` array from offset (e.g, `(- (alength src) offset)` bytes).
 */
alphabase.bytes.copy_slice = (function alphabase$bytes$copy_slice(var_args){
var G__32675 = arguments.length;
switch (G__32675) {
case 3:
return alphabase.bytes.copy_slice.cljs$core$IFn$_invoke$arity$3((arguments[(0)]),(arguments[(1)]),(arguments[(2)]));

break;
case 2:
return alphabase.bytes.copy_slice.cljs$core$IFn$_invoke$arity$2((arguments[(0)]),(arguments[(1)]));

break;
default:
throw (new Error(["Invalid arity: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(arguments.length)].join('')));

}
});

(alphabase.bytes.copy_slice.cljs$core$IFn$_invoke$arity$3 = (function (src,offset,len){
var dst = alphabase.bytes.byte_array(len);
alphabase.bytes.copy.cljs$core$IFn$_invoke$arity$5(src,offset,dst,(0),len);

return dst;
}));

(alphabase.bytes.copy_slice.cljs$core$IFn$_invoke$arity$2 = (function (src,offset){
return alphabase.bytes.copy_slice.cljs$core$IFn$_invoke$arity$3(src,offset,(src.length - offset));
}));

(alphabase.bytes.copy_slice.cljs$lang$maxFixedArity = 3);

/**
 * Concatenate bytes arrays into a single new byte array.
 */
alphabase.bytes.concat = (function alphabase$bytes$concat(var_args){
var args__4870__auto__ = [];
var len__4864__auto___32679 = arguments.length;
var i__4865__auto___32680 = (0);
while(true){
if((i__4865__auto___32680 < len__4864__auto___32679)){
args__4870__auto__.push((arguments[i__4865__auto___32680]));

var G__32681 = (i__4865__auto___32680 + (1));
i__4865__auto___32680 = G__32681;
continue;
} else {
}
break;
}

var argseq__4871__auto__ = ((((0) < args__4870__auto__.length))?(new cljs.core.IndexedSeq(args__4870__auto__.slice((0)),(0),null)):null);
return alphabase.bytes.concat.cljs$core$IFn$_invoke$arity$variadic(argseq__4871__auto__);
});

(alphabase.bytes.concat.cljs$core$IFn$_invoke$arity$variadic = (function (arrs){
var arrs__$1 = cljs.core.remove.cljs$core$IFn$_invoke$arity$2(cljs.core.nil_QMARK_,arrs);
var total_len = cljs.core.reduce.cljs$core$IFn$_invoke$arity$2(cljs.core._PLUS_,cljs.core.map.cljs$core$IFn$_invoke$arity$2((function (p1__32677_SHARP_){
return p1__32677_SHARP_.length;
}),arrs__$1));
var dst = alphabase.bytes.byte_array(total_len);
var arrs_32682__$2 = arrs__$1;
var offset_32683 = (0);
while(true){
var temp__5753__auto___32684 = cljs.core.first(arrs_32682__$2);
if(cljs.core.truth_(temp__5753__auto___32684)){
var src_32685 = temp__5753__auto___32684;
alphabase.bytes.copy.cljs$core$IFn$_invoke$arity$5(src_32685,(0),dst,offset_32683,src_32685.length);

var G__32686 = cljs.core.rest(arrs_32682__$2);
var G__32687 = (offset_32683 + src_32685.length);
arrs_32682__$2 = G__32686;
offset_32683 = G__32687;
continue;
} else {
}
break;
}

return dst;
}));

(alphabase.bytes.concat.cljs$lang$maxFixedArity = (0));

/** @this {Function} */
(alphabase.bytes.concat.cljs$lang$applyTo = (function (seq32678){
var self__4852__auto__ = this;
return self__4852__auto__.cljs$core$IFn$_invoke$arity$variadic(cljs.core.seq(seq32678));
}));

